init python:

    #####################################################################
    #                SPACE TRAVEL
    #####################################################################

    from random import randrange

    class ProjectionStarfield(renpy.Displayable):
        def __init__(self,count=0, depth=0,*args,**kwargs):
            super(renpy.Displayable, self).__init__(*args,**kwargs)

            self.count = count
            self.depth = depth

            self.origin_x = config.screen_width /2
            self.origin_y = config.screen_height /2

            #If a perspective amount is provided, use it. If not, use default.
            try:
                self.perspective = kwargs["perspective"]
            except:
                self.perspective = 128.0

            #If a displayable is provided, use that as the star. If not, make a star to use.
            try:
                self.one_star = kwargs["child"]
            except:
                star_colour = Solid((255,255,255,255))
                self.one_star = Fixed(star_colour,xysize=(1,1))
            self.star_positions()

        def star_positions(self):
            #Create the starting positions for the stars, represented as: [X,Y,Z]
            self.stars = []

            for item in range(self.count):
                star = [randrange(-25,25), randrange(-25,25), randrange(1, self.depth)]
                self.stars.append(star)

        def render(self,width,height,st,at):
            render = renpy.Render(0,0)

            for star in self.stars:

                #Z coordinate decreases each redraw.
                star[2] -= 0.19

                #If the star exits the screen, move it to the back of the projection with random X and Y coordinates.
                if star[2] <= 0:
                    star[0] = randrange(-25,25)
                    star[1] = randrange(-25,25)
                    star[2] = self.depth

                #Convert the 3D coordinates to 2D using perspective projection.
                k = self.perspective / star[2]
                x = int(star[0] * k + self.origin_x)
                y = int(star[1] * k + self.origin_y)

                #Draw the star (if it's visible on screen).
                #Using Linear Interpolation, distant stars are smaller and darker than closer stars.
                if 0 <= x < config.screen_width and 0 <= y < config.screen_height:
                    size = (1 - float(star[2]) / self.depth) * 3
                    shade = (1 - float(star[2]) / self.depth)

                    #Apply the size and shade using Transform()
                    t = Transform(child=self.one_star, zoom=size, alpha=shade)
                    child_render = renpy.render(t,0,0,st,at)
                    render.blit(child_render,(x,y))

            renpy.redraw(self,0)
            return render

        def visit(self):
            return [self.one_star]

#####################################################################
#                WRAPPER
#####################################################################

init:
    define stars = ProjectionStarfield(count=512,depth=16)

screen starfield_scr:
    add stars


label travel(message):
    scene space_bg_smart
    show screen starfield_scr
    "[message]"
    hide screen starfield_scr
    return()


#####################################################################
#					NAVIGATE GALAXY		
#####################################################################
screen navigate_galaxy_scr(starSys):
    #####################################################################
    #					NAV POINTS	
    #####################################################################
    for i in [x for x in GAME.starSys.values() if x.found]:
  
        if i == GAME.getStarSys():
            frame xsize 64 ysize 64 pos i.coord[0], i.coord[1]:
                button action NullAction() tooltip i
                image "05_gui/ico Ship.png" xalign 0.5 yalign 0.5 zoom 0.2
        else:
            frame xsize 64 ysize 64 pos i.coord[0], i.coord[1]:
                button action Return(i) tooltip i
                if not i.unlocked:
                    image "05_gui/ico ITMPadlock.png" xalign 0.5 yalign 0.5 zoom 0.1
        text "{}".format(i.name) size FSIZE pos i.coord[0], i.coord[1]+74

    #####################################################################
    #					TOOLTIPS AND FOOTER		
    #####################################################################
    $ tooltip = GetTooltip()
    if tooltip:
        if "planet" in tooltip.__dict__.keys():
            frame xsize 700 ysize 200 pos 1880,100  xalign 1.0 background Solid("0099ff55"):
                image "02_locations/ico GUI{}_idle.png".format(tooltip.planet)zoom 0.75 yalign 0.6 
                vbox xpos 200 yalign 0.5 xsize 400 spacing 10:
                    text "{}{} System - {} {}{}".format(C_HI_B, tooltip.name, tooltip.race, tooltip.gov, C_HI_E) size FSIZE 
                    text "{}".format(tooltip.description) size FSIZE_MED
                
    #####################################################################
    #                EXIT BUTTON 
    #####################################################################
    frame xsize 350 ysize 64 pos 0,900 background Solid("#00000000") padding 0,0:
        image "05_gui/gui_menu_option.png" yalign 0.5
        textbutton "Exit (X)" yalign 0.5 action Return(False)xpos 20
        button action Return(False)xpos 20
        key "x" action Return (False)
        key "X" action Return (False)    
        key "K_SPACE" action Return (False)    
        

label navigate_galaxy():
    # init screen 
    show screen header()
    scene expression("05_gui/map_galaxy.png") with fade
    play music "audio/orchestral_strings.mp3"
    $ starSys = GAME.getStarSys()

    while True:
        call screen navigate_galaxy_scr(starSys)

        # exit?
        if _return == False: 
            queue sound "audio/click.wav"
            stop music
            scene nav_screen_smart with fade

            return()

        elif not _return.unlocked:
            queue sound "audio/tech_fail.wav"
            "Hypergate Manager" "\"You do not have permission to enter [_return.race] Systems.\""
            if not GAME.mc.hasDone("gate_refused"):
                queue sound "audio/drone_beep.wav"
                mc "\"But I have a Hyperjump License!\""
                mc "\"And a Navigator!\""
                mc "\"And Krell Pet Uniforms for all of my crew!\""
                queue sound "audio/drone_beep.wav"
                bb2 "\"Other races do not allow uncontrolled travel into their Space.\""
                bb2 "\"You need an endorsement to enter foreign Systems.\"" 
                bb2 "\"Try talking to a representative of the Krell.\""
                mc "\"An endorsement?\""
                bb2 "\"Yes, like for a trade or transport mission.\""
                mc "\"I see.\"" 
                mc "\"I might know someone to talk to...\""
            else:
                "Hypergate Manager" "\"Get an endorsement from a member of the [_return.race] Race.\""
            if _return.ID == "SSIDArellarti":
                $ GAME.mc.hasDone("refused_arellarti")

            call quest_updater() from _call_quest_updater_103

        # ================ CR-0395 START
        elif not GAME.questSys.isDone("QID_SERAPHINE_CREW_READY"):
            queue sound "audio/notify.wav"
            mc "\"I better wait for T'Ris to tell me the crew is ready.\""
            mc "\"Those Krell take their regulations very seriously\""
        # ================ CR-0395 END


        elif _return.unlocked:
            $ starSys = _return 
            queue sound "audio/beep.wav"
            call large_notify("JUMPGATE CONTROL", "Travel to {0}{2} System{1} will cost you {0}{3:,} Cr{1} for a one-way hyperjump. Approval of payment will initiate gate transfer.\n\nDo you want to proceed?".format(C_HI_B, C_HI_E, starSys.name, starSys.cost), ["Pay", "Abort"], "05_gui/ico Jumpgate.png", "pink") from _call_large_notify_36
            if _return == "Pay" and GAME.money < starSys.cost:
                mc "\"I cannot afford that jump.\""
                mc "\"I better earn some money first.\""
            elif _return == "Pay":
                call transaction("Jumpgate Fees", -starSys.cost, True) from _call_transaction_26
                stop music                
                "Hypergate Manager" "\"Prepare for warp speed.\""
                scene space_bg_smart with fade
                $ n = 15
                queue sound "audio/teleport.wav"
                scene expression("05_gui/hyperjump.png") with blueflash
                while n:
                    $ n -= 1 
                    queue sound "audio/teleport.wav"
                    scene expression("05_gui/hyperjump.png") with vpunch 
                play sound "audio/explode.wav"

                # switch starsystem and return to space nav screen
                $ GAME.ship.starSysID = starSys.ID
                $ GAME.setSpaceLocID("LIDGate{}".format(starSys.name))
                queue sound "audio/beep.wav"
                scene space_bg_smart with blueflash 
                call hour_passes(18-GAME.hour) from _call_hour_passes_64
                "Navigation Control" "\"Destination [C_HI_B][starSys.name][C_HI_E] reached.\""
                $ GAME.mc.hasDone("first_jump")
                # prep scene    
                call quest_updater() from _call_quest_updater_104       
                play music "audio/ambient_space.wav" fadein 1.0     
                window hide  
                pause
                # arrival intercepts
                if starSys.ID == "SSIDArellarti":
                    call cutscene("uniform_krell_muster") from _call_cutscene_33    
                if starSys.ID == "SSIDIltari":
                    if not nimhe.hasDone("arellarti_return"):
                        nim "\"Finally we can get rid of those stupid uniforms...\""
                        khe "\"I'll second that!\""
                        tri "\"Free uniform choice for the rest of the day.\""
                        mc "\"Fine.\""
                        "You crew is heading to their quarters to change..." with fade
                    python:
                        for i in GAME.crew:
                            if i.uniform == "UID4_Krell":
                                i.uniform = "UID1_Free"
                                i.getDressed()
                            
                return()
                

    return()

#####################################################################
#                NAVIGATE SPACE
#####################################################################

screen navigate_space_scr(*args):
    $ starSys = GAME.getStarSys()
    $ dueMissionPoints = args[0]

    #####################################################################
    #                SPACE LOCS
    #####################################################################
    $ station = {"SSIDArellarti": "LIDStationArellarti", "SSIDIltari": "LIDStationIltari"}[GAME.getStarSys().ID]
    
    for k in starSys.locs.keys():
        $ xCoord = starSys.locs[k].coord[0]
        $ yCoord = starSys.locs[k].coord[1]
        $ l = starSys.locs[k]

        #frame xsize 256 ysize 256 xpos xCoord ypos yCoord xalign 0.5 yalign 0.5 background Solid("#00000000"):
        if l.found:
            imagebutton auto "02_locations/ico {}_%s.png".format(l.guiImg) focus_mask True xalign 0.5 yalign 0.5 xpos xCoord ypos yCoord action Return(["loc", l]) tooltip [l.name, l.coord[0], l.coord[1] ]
            if l.ID in dueMissionPoints: 
                image "05_gui/ico_attention.png"  xpos xCoord-126 ypos yCoord-48 
    key "b" action Return(["loc", starSys.locs[station]])


    $ tooltip = GetTooltip()
    if tooltip:
        # paranoid check                                                    # CR-0337
        $ tDict = tooltip.__dict__                                          # CR-0337
        if tDict != {}:                                                     # CR-0337
            pass                                                            # CR-0337
        else:                                                               # CR-0337
            text "{}".format(tooltip[0]) xpos tooltip[1] ypos tooltip[2]    # CR-0337

    #####################################################################
    #                SHIP
    #####################################################################
    $ l = GAME.getSpaceLoc()
    $ xCoord = l.coord[0]
    $ yCoord = l.coord[1]
    imagebutton auto "02_locations/ico GUIShip_%s.png" focus_mask True  xpos xCoord+84 ypos yCoord+64 xalign 0.5 yalign 0.5 action Return(["ship", None]) tooltip ["Ship", xCoord+112,yCoord+80 ]
    key "x" action Return(["ship", None])
    vbox  xalign 0.5 yalign 0.95:
        text "X = Return To Ship / B = Back to Station / Due Missions: Click on Location with Red '!' Symbol" size FSIZE_MED


label navigate_space():
    # prep scene
    scene nav_screen_smart with fade
    show screen header()
    $ GAME.ship.status = "in space"
    $ GAME.setLocID("LOCSpace")

    # nav screen loop
    while True:


        ##################################################################### # CR-0342
        #					REFRESH BACKGROUND		                          # CR-0342
        ##################################################################### # CR-0342
        scene nav_screen_smart

        #####################################################################
        #					REFRESH VISIBLE MISSION POINTS		
        #####################################################################
        $ navPoints = [x for x in GAME.getStarSys().locs if "Rendezvous" in x]
        $ missionPoints = [x.sLocID for x in GAME.missionSys.missions]
        $ dueMissionPoints = [x.sLocID for x in GAME.missionSys.getDueMissions() if (x.kind == "bounty" or x.due == GAME.day)]
        python:
            for i in navPoints:
                if i in dueMissionPoints:
                    GAME.getSpaceLoc(i).found = True 
                else:
                    GAME.getSpaceLoc(i).found = False 
            if GAME.questSys.inProgress("QID_MULT_FIND"):
                GAME.getSpaceLoc("LIDRendezvous75").found = True
                dueMissionPoints.append("LIDRendezvous75")
            if GAME.questSys.inProgress("QID_MULT_TRANSPORT"):  
                GAME.getSpaceLoc("LIDRendezvous50").found = True
                dueMissionPoints.append("LIDRendezvous50")
            if GAME.questSys.inProgress("QID_SERAPHINE_ARELLARTI_FIND"):  
                GAME.getSpaceLoc("LIDRendezvousArellarti25").found = True
                dueMissionPoints.append("LIDRendezvousArellarti25")    

        #####################################################################
        #					NAV SCREEN		
        #####################################################################
        call screen navigate_space_scr(dueMissionPoints)
        play sound "audio/click.wav"

        if "ship" in _return:
            $ GAME.setLocID("LOCBridge")
            call prepare_scene() from _call_prepare_scene_36
            return()

        elif "loc" in _return:
            $ spaceLoc = _return[1]
            #####################################################################
            #                NAV ACTIONS
            #####################################################################

            if GAME.ship.getSubSysStatus("engines") < 0.1:
                play sound "audio/tech_fail.wav"
                "Navigation Control" "\"Engines are inoperative.\""
                if not  GAME.mc.hasDone("engines inoperative"):
                    mc "\"I better have a look at that engine configuration...\""
                call quest_updater() from _call_quest_updater_105

            #####################################################################
            #					MISSION CHECK		
            #####################################################################
            elif GAME.missionSys.getLocActive(spaceLoc.ID) and spaceLoc.ID == GAME.ship.spaceLocID:
                $ mission = GAME.missionSys.getLocActive(spaceLoc.ID)

                # Transport Mission
                if mission.kind in ["transport", "smuggling"]:
                    if eval(mission.cond):
                        call mission_scripts(mission, "on_complete") from _call_mission_scripts
                        $ GAME.missionSys.purgeMission(mission)  

                # Bounty Mission 
                elif mission.kind == "bounty":
                    queue sound "audio/notify.wav"
                    call simple_notify("BOUNTY MISSION", "Locating hostiles...", ["Engage", "Abort"], "05_gui/ico_Hostile.png", "red") from _call_simple_notify_50
                    if _return == "Engage":
                        hide screen header
                        call mg_combat_scenario(mission.attr["mProfile"]) from _call_mg_combat_scenario_1
                        $ result = _return
                        if "victory" in result: # EXP returned
                            $ damage = result[1]
                            $ exp = result[2]
                            queue sound "audio/triumph.wav"
                            call simple_notify("VICTORY", "+[exp:,] EXP gained", ["Continue"], "05_gui/ico_Cup.png") from _call_simple_notify_51
                            queue sound "audio/click.wav"            
                            $ GAME.mc.exp += exp
                            call attr_mod(GAME.mc, "NOT", 1, 20, 100, True) from _call_attr_mod_46
                            call mission_scripts(mission, "on_complete") from _call_mission_scripts_1
                            $ GAME.missionSys.purgeMission(mission) 
                            $ GAME.mc.hasDone("first_bounty") # CR-0264
                            
                        else:
                            $ damage = result[1]
                            "You decide to try your luck another time..."
                            call attr_mod(GAME.mc, "NOT", -1, 0, 100, True) from _call_attr_mod_47

                        if damage:  
                            queue sound "audio/notify.wav"
                            call simple_notify("DAMAGE REPORT", "Subunits lost: {}".format(len(damage)), ["Continue"], "05_gui/ico Ship.png") from _call_simple_notify_52
                            queue sound "audio/click.wav"   
                        show screen header()

                    call quest_updater() from _call_quest_updater_106                     


            #####################################################################
            #                MINING
            #####################################################################
            elif spaceLoc.ID in ["LIDAsteroidsOuter"] and not GAME.ship.hasSubSysType("ITMMiningMkII"):
                mc "\"I need at least a Mining Laser MkII to mine this Field...\""

            elif spaceLoc.ID in ["LIDRubbleIltari", "LIDAsteroidsIltari", "LIDAsteroidsOuter"] and spaceLoc.ID == GAME.ship.spaceLocID :
                $ mChoice = False
                # Intercepts
                if GAME.questSys.inProgress("QID_PIRATE_TASK") and spaceLoc.ID == "LIDAsteroidsIltari":
                    queue sound "audio/notify.wav"
                    call large_notify("GHAD THE RENEGADE", "From the information Vigo provided, you are able to locate the renegade pirate in the Asteroid Field.\n\nDo you want to confront him?", ["Confront", "Abort", "Mining"], "05_gui/ico Ship.png", "orange") from _call_large_notify_37
                    if _return == "Abort":
                        $ mChoice = True
                    elif _return == "Confront":
                        hide screen header
                        call mg_combat_scenario("renegade_ghad") from _call_mg_combat_scenario_2
                        $ mChoice = True
                        show screen header()
            
                if GAME.questSys.inProgress("QID_NIMHE_RETRIEVE_KICKOFF") and spaceLoc.ID == "LIDAsteroidsOuter":
                    queue sound "audio/notify.wav"
                    call large_notify("THE LOST MILITARY BASE", "From the information Nimhe provided, you are able to locate the military research station among the asteroids.\n\nDo you want to explore it?", ["Explore", "Abort", "Mining"], "05_gui/ico Ship.png", "orange") from _call_large_notify_38
                    if _return == "Abort":
                        $ mChoice = True
                    elif _return == "Explore":
                        hide screen header
                        call cutscene("shell_find") from _call_cutscene_34
                        call hour_passes() from _call_hour_passes_65
                        $ mChoice = True
                        scene nav_screen_smart with fade
                        show screen header()

                #  Mining
                if mChoice:
                    pass               
                elif GAME.ship.getSubSysStatus("mining") <= 0.0:
                    play sound "audio/beep.wav"
                    "Ship Control" "\"Mining laser is offline.\""
                elif GAME.hour >= 18:
                    mc "\"I should resume that, when I am better rested...\""
                else:
                    #hide screen header
                    hide screen header
                    call mg_mining_pick(spaceLoc.name.upper()) from _call_mg_mining_pick
                    call hour_passes(18-GAME.hour) from _call_hour_passes_66
                    show screen header

            #####################################################################
            #                MULTIVERSE POD
            #####################################################################
            elif spaceLoc.ID in ["LIDRift"] and spaceLoc.ID == GAME.ship.spaceLocID :
                #hide screen header
                hide screen header
                call multiverse_manager("retrieve") from _call_multiverse_manager_1
                show screen header

            #####################################################################
            #                HYPERGATE
            #####################################################################
            elif spaceLoc.ID in ["LIDGateIltari", "LIDGateArellarti"] and spaceLoc.ID == GAME.ship.spaceLocID :    
                if "gate_talk" not in tris.done:
                    mc "\"I'm not sure I should venture out ...\""
                    if not GAME.questSys.isActive('QID_VEE_FAMILIARIZE'): 
                        mc "\"I have the feeling my crew is not complete yet...\""
                    elif GAME.questSys.isActive('QID_SERAPHINE_KICKOFF'):
                        mc "\"I am ready to move beyond Iltari...\""
                        mc "\"I should talk to T'Ris.\""
                    else:
                        mc "\"I better find out more about this system first...\""

                elif not GAME.ship.hasSubSys("hyperdrive"):
                    queue sound "audio/drone_beep.wav"
                    bb2 "\"We need a Hyperdrive Subsystem to use the Gate, Captain [GAME.mc.name].\""
                    mc "\"Right.\""
                    mc "\"I better buy one then.\""
                    bb2 "\"Make sure to fully configure it.\""
                    bb2 "\"Hyperdrives need full power to use the Gate.\""
                    mc "\"Understood.\""

                elif GAME.ship.getSubSysStatus("hyperdrive") < 99: # paranoid boundary 
                    queue sound "audio/drone_beep.wav"
                    bb2 "\"We need our Hyperdrive Subsystem at 100 percent to use the Gate, Captain [GAME.mc.name].\""
                    bb2 "\"Otherwise we might end up lost in Hyperspace...\""
                    mc "\"Right, I forgot.\""

                elif not GAME.questSys.isDone('QID_SERAPHINE_CLASS_TRIS'):
                    queue sound "audio/beep.wav"
                    "Jumpgate Control" "\"Jumpgate Access Declined.\""
                    mc "\"Arrgghh....!\""
                    "Jumpgate Control" "\"You do not possess the required [C_HI_B]Hyperjump License.[C_HI_E]\""
                    if not GAME.mc.hasDone("hypergate_reject"):
                        mc "\"Where can I obtain such a License?\""
                        "Jumpgate Control" "\"Hyperjump Licenses are issued at Iltari Station Administration.\""
                    "Jumpgate Control" "\"Iltari Gate Control Out.\""
                    call quest_updater(2) from _call_quest_updater_107

                elif GAME.hour > 17:
                    mc "\"I should do that when I am better rested.\""

                else:   
                    call navigate_galaxy() from _call_navigate_galaxy

            #####################################################################
            #                WAYPOINTS / QUEST STUFF
            #####################################################################
            elif spaceLoc.ID == "LIDRendezvous75" and GAME.questSys.inProgress("QID_MULT_FIND") and spaceLoc.ID == GAME.ship.spaceLocID:
                scene space_bg_smart
                show image "05_gui/mask_cockpit_space.png"                 
                mc "\"Now let's see whether we can find that crate...\""
                call simple_notify("SCANNING", "You scan the area...", ["Continue"], "05_gui/ico Ship.png") from _call_simple_notify_53 
                queue sound "audio/success.wav"
                $ item = GAME.items["ITMCrateLiquor"]
                call find_notify(item, "ITEM FOUND") from _call_find_notify_19 
                queue sound "audio/load.wav"
                $ GAME.setLocID("LOCCargo")
                mc "\"Let's have a look at what we found...\""  
                scene room_cargo_smart with fade 
                "You open the crate in the cargobay..."
                $ item = GAME.items["ITMLiquorVortex"] 
                call find_notify(item, "ITEM FOUND", 5) from _call_find_notify_20 
                $ GAME.mc.hasDone("vortex_found")
                mc "\"Looks mighty expensive...\""
                mc "\"Let's bring that back to Ylyee...\""
                call quest_updater() from _call_quest_updater_108
                $ GAME.mc.inventory += [item]*5
                call navigate_to("LOCBridge") from _call_navigate_to_53
                #$ GAME.getStarSys().locs["LIDRendezvous75"].found = True
                return()

            elif spaceLoc.ID == "LIDRendezvous50" and GAME.questSys.inProgress("QID_MULT_TRANSPORT") and spaceLoc.ID == GAME.ship.spaceLocID and "escort" in ylyee.status: # CR-0382
                scene expression("05_gui/mask_cockpit_space.png") with fade 
                mc "\"Let's scan for crafts in the vicinity...\"" 
                queue sound "audio/teleport.wav"
                scene expression("06_cutscenes/cutscene_voronian_cruiser_two.png") with dissolve
                mc  "\"Whoaaa...\""
                queue sound "audio/beep.wav"
                "Voronian Cruiser" "\"This is Imperial Voronian Cruiser Lagdash.\""
                "Voronian Cruiser" "\"Hand over her Exalted Highness immediately!\""
                mc "\"Highness?\"" 
                yly "\"That's me.\"" 
                mc "\"I thought you were some kind of Diplomat?\""
                yly "\"In a sense...\"" 
                yly "\"Lagdash, stand down and prepare for transport.\""
                "Voronian Cruiser" "\"Affirmative.\""
                yly "\"You have been of great service to me.\""
                yly "\"Accept this as a token of my gratitude.\""
                $ item = GAME.items["ITMMultiPod"]
                queue sound "audio/success.wav"
                call find_notify(item, "You receive ") from _call_find_notify_21 
                $ GAME.mc.inventory.append(item)
                mc "\"What is that?\""
                yly "\"A mysterious and powerful device...\""
                yly "\"It can extend itself through the Multiverse...\""
                mc "\"Through what?\""
                yly "\"Use it, when you are ready.\""
                mc "\"Ready?\""
                yly "\"You will know.\"" 
                yly "\"Lagdash, ready to transport.\""
                queue sound "audio/teleport.wav"
                mc "\"Whoaa...\"" with blueflash 
                scene expression("05_gui/mask_cockpit_space.png") with dissolve 
                mc "\"That was odd...\"" 
                $ GAME.mc.hasDone('ylyee_escorted')
                $ ylyee.status.remove("escort") # CR-0382
                mc "\"I better store that pod safely until I am ready to use it.\"" 
                $ GAME.mc.exp += 1000                
                call quest_updater() from _call_quest_updater_109
                call navigate_to("LOCBridge") from _call_navigate_to_54
                #$ GAME.getStarSys().locs["LIDRendezvous50"].found = False
                return()

            elif spaceLoc.ID == "LIDRendezvousArellarti25" and GAME.questSys.inProgress("QID_SERAPHINE_ARELLARTI_FIND") and spaceLoc.ID == GAME.ship.spaceLocID:
                queue sound "audio/notify.wav"
                call large_notify("RESCUE QUEST!", "Scanning the dense Asteroid Field for anomalous signatures, you locate the vessel of Princess Seraphine. A large group of Krell Lashers is searching nearby...\n\nWhat do you want to do?", ["Attack", "Withdraw"], "05_gui/ico Quest.png", "orange") from _call_large_notify_39
                if _return == "Withdraw":
                    $ mChoice = True
                    "You withdraw until you are better prepared..."
                elif _return =="Attack":
                    hide screen header
                    call mg_combat_scenario("rescue_seraphine") from _call_mg_combat_scenario_3
                    $ mChoice = True
                    show screen header()                    

            #####################################################################
            #                DOCKING
            #####################################################################

            elif spaceLoc.ID in ["LIDStationIltari"] and GAME.ship.spaceLocID == spaceLoc.ID and len([x for x in GAME.ship.cargo if not spaceLoc.isLegal(x)]) > GAME.ship.cargoLimitCloak():
                play sound "audio/drone_beep.wav"
                bb2 "\"I recommend to not dock here.\""
                bb2 "\"You are carrying illegal wares which are not, ahem, cloaked.\""
                bb2 "\"You should eject them prior to docking.\""
                mc "\"Right...\""
                scene nav_screen_smart with fade

            elif spaceLoc.ID in ["LIDStationIltari"] and GAME.ship.spaceLocID == spaceLoc.ID:
                scene expression ("06_cutscenes/cutscene_station_one.png") with fade
                play sound "audio/beep.wav"
                $ response = "Proceed"
                if not GAME.mc.hasDone("docked iltari"):
                    call large_notify("{} Control".format(spaceLoc.name), "\"This is {} Control. Your Docking request has been received. Please standby for Docking Procedure.\n\nDocking fee will be 200 Credits.\"".format(spaceLoc.name), ["Proceed", "Abort"], "05_gui/ico Station.png") from _call_large_notify_40
                    $ response = _return
                if response == "Proceed":
                    if GAME.money < 200:
                        "You lack the required docking fees."
                        scene nav_screen_smart with fade
                    else:
                        # scene expression ("06_cutscenes/cutscene_station_two.png") with fade
                        # window hide
                        # pause
                        scene expression ("06_cutscenes/cutscene_station_three.png") with fade
                        window hide
                        pause
                        play sound "audio/load.wav"
                        $ GAME.ship.status = "docked"
                        #if not GAME.locs["LOCDock"].found:
                            #$ GAME.locs["LOCDock"].found = True
                        $ GAME.setLocID("LOCBridge")
                        call prepare_scene() from _call_prepare_scene_37
                        call transaction("Docking Fees", -200, True) from _call_transaction_27
                        if "first docking" not in GAME.mc.done:
                            play sound "audio/notify.wav"
                            tri "\"Well, you managed to get us here in one piece.\""
                            tri "\"Impressive.\""
                            tri "\"Thankfully, most ship functions are automated...\""
                            tri "\"I recommend you look for that map now.\""
                            tri "\"I shall continue my diagnostic of the Ship's systems.\""
                            $ GAME.mc.hasDone("first docking")
                        return()
                elif _return == "Abort":
                    scene nav_screen_smart with fade

            elif spaceLoc.ID in ["LIDPirate"] and GAME.ship.spaceLocID == spaceLoc.ID:
                scene expression ("06_cutscenes/cutscene_pirate_hideout.png") with fade
                play sound "audio/beep.wav"
                $ response = "Proceed"
                call large_notify("{} Control".format(spaceLoc.name), "\"This is Tango 4. Your Docking request has been received. Please standby for Docking Procedure.\n\nDocking fee will be 10,000 Credits.\"", ["Proceed", "Abort"], "05_gui/ico_Pirate.png", "orange") from _call_large_notify_41
                $ response = _return
                if response == "Proceed":
                    $ GAME.mc.hasDone("docked_pirate")
                    if GAME.money < 10000:
                        "You lack the required docking fees."
                        scene nav_screen_smart with fade
                    else:
                        scene expression ("06_cutscenes/cutscene_pirate_hideout_one.png") with fade
                        window hide
                        pause
                        play sound "audio/load.wav"
                        $ GAME.ship.status = "docked"
                        $ GAME.setLocID("LOCBridge")
                        call prepare_scene() from _call_prepare_scene_38
                        call transaction("Docking Fees", -10000, True) from _call_transaction_28
                        if not GAME.mc.hasDone("first_docking_pirate"):
                            play sound "audio/notify.wav"
                            nim "\"So far so good.\""
                            nim "\"But we better tread lightly here.\""
                            nim "\"I suggest we pay Vigo, my contact, a visit.\""
                            nim "\"I think we can find him in the Cantina.\""
                        return()

                elif _return == "Abort":
                    scene nav_screen_smart with fade

            elif spaceLoc.ID in ["LIDStationArellarti"] and GAME.ship.spaceLocID == spaceLoc.ID:
                scene expression ("06_cutscenes/cutscene_arellarti_station_exterior.png") with fade
                play sound "audio/beep.wav"
                $ response = "Proceed"
                $ fee = 5000
                call large_notify("{} Control".format(spaceLoc.name), "\"This is Arellarti Station. Your Docking request has been received. Please standby for Docking Procedure.\n\nDocking fee will be [fee:,] Credits.\"", ["Proceed", "Abort"], "05_gui/ico_arellarti_station.png", "green") from _call_large_notify_42
                $ response = _return
                if response == "Proceed":
                    $ GAME.mc.hasDone("docked_arellarti_station")
                    if GAME.money < fee:
                        "You lack the required docking fees."
                        scene nav_screen_smart with fade
                    else:
                        scene expression ("06_cutscenes/cutscene_arellarti_station.png") with fade
                        window hide
                        pause
                        play sound "audio/load.wav"
                        $ GAME.ship.status = "docked"
                        $ GAME.setLocID("LOCBridge")
                        call prepare_scene() from _call_prepare_scene_39
                        call transaction("Docking Fees", -fee, True) from _call_transaction_29
                        if not GAME.mc.hasDone("first_docking_arellarti"):
                            play sound "audio/notify.wav"
                            mc "\"So far so good.\""
                            mc "\"I wonder what opportunities exist for us here...\""
                            mc "\"Those Krell seem very business minded...\""
                        return()

                elif _return == "Abort":
                    scene nav_screen_smart with fade


            #####################################################################
            #               SPACE LOCS
            #####################################################################

            elif GAME.ship.getSubSysStatus("engines") < spaceLoc.zone:
                play sound "audio/tech_fail.wav"
                "Navigation Control" "\"Destination cannot be reached with current engine performance.\""
                if not GAME.mc.hasDone("refuse navigate"):
                    mc "\"I better earn some money and upgrade my engines...\""

                call quest_updater() from _call_quest_updater_110

            #####################################################################
            #                TENARIS
            #####################################################################
            elif spaceLoc.ID == "LIDTenaris" and GAME.ship.getSubSysStatus("weapons") == 0:
                play sound "audio/drone_beep.wav"
                bb2 "\"The area around Tenaris is considered dangerous.\""
                bb2 "\"There are slave traders and pirates around.\""
                bb2 "\"You shouldn't go there without shields and weapons.\""
                mc "\"I see...\""
                mc "\"I better get my ship ugraded then...\""

            #####################################################################
            #                JUNKYARD
            #####################################################################
            elif spaceLoc.ID == "LIDJunkyardIltari" and spaceLoc.ID == GAME.ship.spaceLocID:
                # argus not ready
                if GAME.ship.getSubSysStatus("uplink") < 80 or nimhe not in GAME.crew: # CR-0327
                    play sound "audio/beep.wav"
                    queue sound "audio/red alert.wav"
                    pga "\"This area is interdicted.\"" with redflash
                    pga "\"Violators will be disintegrated.\""
                    if not GAME.mc.hasDone("intro_interdiction"):
                        play sound "audio/drone_beep.wav"
                        bb2 "\"Those drones are not to be trifled with.\""
                        mc "\"I need to find a way to incapacitate them...\""
                        bb2 "\"Direct confrontation is not advised.\""
                        bb2 "\"They are Precursor technology and virtually indestructible.\""
                        bb2 "\"Otherwise the wrecks would long have been stripped of their AI Cores...\""
                        mc "\"A more surreptitious approach then...\""
                        mc "\"Maybe I can find a competent hacker to take them offline...\""
                        call quest_updater() from _call_quest_updater_111
                    else:
                        mc "\"This was a, ahem... navigational error.\""
                        mc "\"I'm gone already...\""
                elif GAME.hour >= 18:
                    mc "\"I should do that when I am better rested...\""
                # argus at 100% => Precursor exploration
                elif GAME.ship.getSubSysStatus("shields") == 0 or GAME.ship.getSubSysStatus("weapons") == 0:
                    queue sound "audio/drone_beep.wav"
                    if not GAME.mc.hasDone("illegal_bot_warning"):
                        bb2 "\"I would not go in there yet, Captain [GAME.mc.name].\""
                        mc "\"Why?\""
                        bb2 "\"Although the Argus allows us to sneak in, dangers lurk inside.\""
                        bb2 "\"Our ship should at least be equipped with shields and weapons...\""
                        mc "\"Where can I get those...?\""
                        bb2 "\"There are Pirates who are willing to sell them to you for a price.\""
                        bb2 "\"Nimhe might be able to tell you how to find them...\""
                        mc "\"How so?\""
                        bb2 "\"When she was trading in illegal bots she built up contacts...\""
                        bb2 "\"Just ask her about her illegal bots...\""
                        call quest_updater() from _call_quest_updater_112
                    else:
                        bb2 "\"We better arm our ship before going in there...\""
                        mc "\"Ah, right.\""
                        mc "\"We should pay the Pirate Base a visit for that.\""


                elif GAME.getStarSys().ID+"_"+"junkyard_3" not in GAME.mc.done:
                    scene expression("11_backgrounds/backdrop_junkyard.png") with fade
                    mc "\"Now let's see whether that money for the Argus Uplink was well spent...\""
                    "Scrambling the Guardian's sensors, you make your way into the Junkyard..." with fade
                    $ GAME.mc.hasDone('precursor_core_found')
                    # select scenario 
                    $ scenario = False
                    if GAME.getStarSys().ID+"_"+"junkyard_1" not in GAME.mc.done:
                        $ scenario = "junkyard_1"
                    elif GAME.getStarSys().ID+"_"+"junkyard_2" not in GAME.mc.done:
                        $ scenario = "junkyard_2"
                    elif GAME.getStarSys().ID+"_"+"junkyard_3" not in GAME.mc.done:
                        $ scenario = "junkyard_3"

                    if scenario:
                        call mg_combat_scenario(scenario) from _call_mg_combat_scenario_4
                        $ result = _return
                        if "victory" in result: # EXP returned
                            $ damage = result[1]
                            $ exp = result[2]
                            queue sound "audio/triumph.wav"
                            call simple_notify("VICTORY", "+[exp:,] EXP gained", ["Continue"], "05_gui/ico_Cup.png") from _call_simple_notify_54
                            queue sound "audio/click.wav"            
                            $ GAME.mc.exp += exp
                            call attr_mod(GAME.mc, "NOT", 1, 50, 100, True) from _call_attr_mod_48                        
                        else:
                            mc "\"That was close...\""
                        if scenario == "junkyard_3":
                            tri "\"Excellent!\""
                            tri "\"We have gained a Hyperspace map fragment!\""
                            call attr_mod(tris, "APP", 5, 100, 100, True) from _call_attr_mod_49
                        call hour_passes(18-GAME.hour) from _call_hour_passes_67
                        scene nav_screen_smart with fade
                        show screen header()
                    else:
                        mc "\"There is nothing for me left to discover here...\""
                        mc "\"I should look for Precursor sites in other Star Systems...\""

                elif GAME.getStarSys().ID+"_"+"junkyard_3" in GAME.mc.done:
                    queue sound "audio/notify.wav"
                    mc "\"I have cleaned out that location already...\""
                    mc "\"Maybe there are similar locations in other Star Systems...\""
            #####################################################################
            #                ANOMALY
            #####################################################################
            elif spaceLoc.ID == "LIDAnomalyIltari" and GAME.questSys.inProgress('QID_MAIN_ANOMALY') and spaceLoc.ID == GAME.ship.spaceLocID:
                if GAME.hour > 18:
                    mc "\"We should rest before venturing inside...\""
                else:
                    call cutscene("anomaly investigate") from _call_cutscene_35
                    $ GAME.hour = 20
                    $ GAME.setLocID("LOCCargo")
                    call prepare_scene() from _call_prepare_scene_40
                    return()


            #####################################################################
            #                KRELL / DOME
            #####################################################################
            elif spaceLoc.ID == "LIDDomeArellarti" and spaceLoc.ID == GAME.ship.spaceLocID:
                play sound "audio/beep.wav"
                "Arellarti Dome Administrator" "\"No Access For Humans.\""
                mc "\"I see...\""
                mc "\"I better go elsewhere then...\""

            #####################################################################
            #                KRELL / LAB
            #####################################################################
            elif spaceLoc.ID == "LIDLabsArellarti" and spaceLoc.ID == GAME.ship.spaceLocID:
                play sound "audio/beep.wav"
                "Kranor Labs Administrator" "\"Top Secret Research going on here.\""
                "Kranor Labs Administrator" "\"Move along!\""
                mc "\"I see...\""
                mc "\"I better go elsewhere then...\""

            #####################################################################
            #					EXECUTE TRAVEL							  #
            #####################################################################
            elif _return[1].ID != GAME.ship.spaceLocID: # travel
                if GAME.hour >= 22:
                    mc "\"I should resume exploring tomorrow...\""
                else:
                    $ tgtLocID = _return[1].ID
                    $ tgtLoc = _return[1] 
                    call travel("You speed towards your target...") from _call_travel
                    $ GAME.hour += 1

                    #####################################################################
                    #					KRELL BELT CROSSING		
                    #####################################################################
                    if GAME.getStarSys().ID == "SSIDArellarti" and "belt_crossed" not in GAME.mc.doneToday and GAME.getSpaceLoc().zone >=50 and tgtLoc.zone <= 25:
                        queue sound "audio/notify.wav"
                        call large_notify("THE ASTEROID BELT", "Entering the dense Arellarti Asteroid Belt, you must decide on a course of action.\n\nYou can either risk damage or navigate the pirate infested passages.", ["Damage", "Passage", "Abort"], "05_gui/ico Ship.png", "green") from _call_large_notify_43 
                        if _return == "Abort":
                            "You turn back your ship and reconsider..."
                            $tgtLocID = GAME.ship.spaceLocID
                        elif _return == "Damage" and random.randint(1,100) > 30:
                            call check_occurrence(tgtLoc, random.choice(["OCCAsteroids001"])) from _call_check_occurrence
                            if random.randint(1,100) > 50:
                                call check_occurrence(tgtLoc, random.choice(["OCCWreckKrell02", "OCCBotContainer001"])) from _call_check_occurrence_1
                        elif _return == "Damage":
                            "Unexpectedly, you make it through the belt without damage..."
                        elif _return == "Passage" and random.randint(1,100) > 30:
                            call check_occurrence(tgtLoc, random.choice(["OCCHostileKrell01", "OCCHostileKrell02"])) from _call_check_occurrence_2 
                        elif _return == "Passage":
                            "Unexpectedly, you make it through the belt unscathed..."
                        
                        call travel("You resume your travels...") from _call_travel_1
                        $ GAME.mc.hasDoneToday("belt_crossed")
                            
                    #####################################################################
                    #					GENERAL OCCURRENCE		
                    #####################################################################
                    elif "occurrence" not in GAME.mc.doneToday and random.randint(1,100) > 50 and GAME.day > 2:
                        call check_occurrence(tgtLoc) from _call_check_occurrence_3
                        call achievement_updater() from _call_achievement_updater
                        $ GAME.mc.hasDoneToday("occurrence")
                        if _return:
                            if _return == True:
                                pass
                            elif "newloc" in _return:
                                $ tgtLocID = _return[1]
                        call travel("You resume your travels...") from _call_travel_2

                    $ GAME.ship.spaceLocID = tgtLocID
                    scene nav_screen_smart with fade


            #####################################################################
            #					MISSION WITHOUT REQUIRED CARGO		
            #####################################################################
            elif GAME.missionSys.getLocActive(spaceLoc.ID, "loc_only") and spaceLoc.ID == GAME.ship.spaceLocID:
                queue sound "audio/notify.wav"
                mc "\"I don't have all the required cargo loaded yet to fulfil this mission...\"" 
                mc "\"I better check my manifest...\"" 

            #####################################################################
            #					DEFAULT		
            #####################################################################
            else:
                mc "\"There is nothing for me to do here right now...\""
